# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.device_mount_system_api import DeviceMountSystemApi


class TestDeviceMountSystemApi(unittest.TestCase):
    """DeviceMountSystemApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DeviceMountSystemApi()

    def tearDown(self) -> None:
        pass

    def test_get_tray_description(self) -> None:
        """Test case for get_tray_description

        GET description of Tray
        """
        pass

    def test_get_tray_present(self) -> None:
        """Test case for get_tray_present

        GET state of Port Module Relay
        """
        pass

    def test_get_tray_uuid(self) -> None:
        """Test case for get_tray_uuid

        GET UUID of Tray
        """
        pass

    def test_put_tray_description(self) -> None:
        """Test case for put_tray_description

        PUT description of Tray
        """
        pass

    def test_put_tray_uuid(self) -> None:
        """Test case for put_tray_uuid

        PUT UUID of Tray
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.devices_api import DevicesApi


class TestDevicesApi(unittest.TestCase):
    """DevicesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DevicesApi()

    def tearDown(self) -> None:
        pass

    def test_get_current(self) -> None:
        """Test case for get_current

        GET current reading of device
        """
        pass

    def test_get_device_device_id_buttons(self) -> None:
        """Test case for get_device_device_id_buttons

        GET all buttons for device
        """
        pass

    def test_get_device_device_id_leds(self) -> None:
        """Test case for get_device_device_id_leds

        GET all leds for Device
        """
        pass

    def test_get_device_device_id_ports(self) -> None:
        """Test case for get_device_device_id_ports

        GET all Ports for Device
        """
        pass

    def test_get_device_device_id_temperature_ports(self) -> None:
        """Test case for get_device_device_id_temperature_ports

        GET all temperature ports for device
        """
        pass

    def test_get_device_id_port_index(self) -> None:
        """Test case for get_device_id_port_index

        GET status of port
        """
        pass

    def test_get_device_port_current(self) -> None:
        """Test case for get_device_port_current

        GET current reading of device Port
        """
        pass

    def test_get_device_port_module_led_state(self) -> None:
        """Test case for get_device_port_module_led_state

        GET state of Port Module Led
        """
        pass

    def test_get_device_port_module_relay_state(self) -> None:
        """Test case for get_device_port_module_relay_state

        GET state of Port Module Relay
        """
        pass

    def test_get_device_port_voltage(self) -> None:
        """Test case for get_device_port_voltage

        GET voltage reading of device Port
        """
        pass

    def test_get_device_rotation_angle(self) -> None:
        """Test case for get_device_rotation_angle

        GET Rotation Angle
        """
        pass

    def test_get_device_rotation_speed(self) -> None:
        """Test case for get_device_rotation_speed

        GET Turntable Speed
        """
        pass

    def test_get_device_uuid_deprecated(self) -> None:
        """Test case for get_device_uuid_deprecated

        GET uuid from database
        """
        pass

    def test_get_devices(self) -> None:
        """Test case for get_devices

        GET list of devices
        """
        pass

    def test_get_devices_button(self) -> None:
        """Test case for get_devices_button

        GET status of button
        """
        pass

    def test_get_devices_index(self) -> None:
        """Test case for get_devices_index

        GET single device
        """
        pass

    def test_get_devices_led(self) -> None:
        """Test case for get_devices_led

        GET status of Led
        """
        pass

    def test_get_devices_temperature(self) -> None:
        """Test case for get_devices_temperature

        GET temperature reading
        """
        pass

    def test_get_fan_speed(self) -> None:
        """Test case for get_fan_speed

        GET device fan speed
        """
        pass

    def test_get_fan_target_temperature(self) -> None:
        """Test case for get_fan_target_temperature

        GET device fan target temperature
        """
        pass

    def test_get_fan_temperature(self) -> None:
        """Test case for get_fan_temperature

        GET device fan temperature
        """
        pass

    def test_get_firmware_version(self) -> None:
        """Test case for get_firmware_version

        GET Device Firmware Version
        """
        pass

    def test_get_image(self) -> None:
        """Test case for get_image

        GET Image
        """
        pass

    def test_get_image_names(self) -> None:
        """Test case for get_image_names

        GET Image Names
        """
        pass

    def test_get_message_from_rx_buffer_deprecated(self) -> None:
        """Test case for get_message_from_rx_buffer_deprecated

        GET message from RX table
        """
        pass

    def test_get_message_from_tx_buffer_deprecated(self) -> None:
        """Test case for get_message_from_tx_buffer_deprecated

        GET message from TX table
        """
        pass

    def test_get_port(self) -> None:
        """Test case for get_port

        GET status of Port by id
        """
        pass

    def test_get_port_led_state(self) -> None:
        """Test case for get_port_led_state

        GET state of Port LED
        """
        pass

    def test_get_port_setup_status(self) -> None:
        """Test case for get_port_setup_status

        GET setup status of Port
        """
        pass

    def test_get_port_states(self) -> None:
        """Test case for get_port_states

        GET port states by Port id
        """
        pass

    def test_get_ports(self) -> None:
        """Test case for get_ports

        GET status of all ports
        """
        pass

    def test_get_relay_state(self) -> None:
        """Test case for get_relay_state

        GET state of relay
        """
        pass

    def test_get_temperature_range(self) -> None:
        """Test case for get_temperature_range

        GET Temperature Range
        """
        pass

    def test_get_temperature_thresholds(self) -> None:
        """Test case for get_temperature_thresholds

        GET Temperature Thresholds
        """
        pass

    def test_get_turntable_calibration_data(self) -> None:
        """Test case for get_turntable_calibration_data

        GET Turntable Calibration Values
        """
        pass

    def test_get_voltage(self) -> None:
        """Test case for get_voltage

        GET voltage reading of device
        """
        pass

    def test_put_auto_calibrate_turntable(self) -> None:
        """Test case for put_auto_calibrate_turntable

        PUT Calibration
        """
        pass

    def test_put_device_deprecated(self) -> None:
        """Test case for put_device_deprecated

        PUT Add evice
        """
        pass

    def test_put_device_device_id_description(self) -> None:
        """Test case for put_device_device_id_description

        PUT a description for a Device
        """
        pass

    def test_put_device_device_id_name(self) -> None:
        """Test case for put_device_device_id_name

        PUT a name for a Device
        """
        pass

    def test_put_device_id_label(self) -> None:
        """Test case for put_device_id_label

        PUT a Port label
        """
        pass

    def test_put_device_port_module_led_state(self) -> None:
        """Test case for put_device_port_module_led_state

        PUT state of Port Module LED
        """
        pass

    def test_put_device_port_module_relay_state(self) -> None:
        """Test case for put_device_port_module_relay_state

        PUT state of Port Module Relay
        """
        pass

    def test_put_device_rotation_angle(self) -> None:
        """Test case for put_device_rotation_angle

        PUT Rotation
        """
        pass

    def test_put_device_rotation_angle_continuous(self) -> None:
        """Test case for put_device_rotation_angle_continuous

        PUT Continious Rotation
        """
        pass

    def test_put_device_rotation_speed(self) -> None:
        """Test case for put_device_rotation_speed

        PUT Turntable Speed
        """
        pass

    def test_put_devices_led_index(self) -> None:
        """Test case for put_devices_led_index

        PUT state of Led
        """
        pass

    def test_put_devices_ports(self) -> None:
        """Test case for put_devices_ports

        PUT state of port
        """
        pass

    def test_put_halt_rotation(self) -> None:
        """Test case for put_halt_rotation

        PUT Halt Rotation
        """
        pass

    def test_put_port_led_state(self) -> None:
        """Test case for put_port_led_state

        PUT state of Port LED
        """
        pass

    def test_put_port_port_id_label(self) -> None:
        """Test case for put_port_port_id_label

        PUT the label for a Port
        """
        pass

    def test_put_port_port_id_state_label(self) -> None:
        """Test case for put_port_port_id_state_label

        PUT state label
        """
        pass

    def test_put_ports_pulse(self) -> None:
        """Test case for put_ports_pulse

        PUT Port into state for period of time
        """
        pass

    def test_put_relay_state(self) -> None:
        """Test case for put_relay_state

        PUT state of Relay
        """
        pass

    def test_put_serial_test_message_deprecated(self) -> None:
        """Test case for put_serial_test_message_deprecated

        Serial Message Test
        """
        pass

    def test_put_state_by_port_id(self) -> None:
        """Test case for put_state_by_port_id

        PUT state of port
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.models.db_button_state import DbButtonState

class TestDbButtonState(unittest.TestCase):
    """DbButtonState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbButtonState:
        """Test DbButtonState
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbButtonState`
        """
        model = DbButtonState()
        if include_optional:
            return DbButtonState(
                button_state_id = '',
                button_id = '',
                label = '',
                index = 1
            )
        else:
            return DbButtonState(
                button_state_id = '',
                button_id = '',
                label = '',
                index = 1,
        )
        """

    def testDbButtonState(self):
        """Test DbButtonState"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr, field_validator
from typing import Any, Dict, Optional
from typing_extensions import Annotated
from DeviceServer.models.attenuation_state import AttenuationState
from DeviceServer.models.channel_attenuation_state import ChannelAttenuationState

from DeviceServer.api_client import ApiClient, RequestSerialized
from DeviceServer.api_response import ApiResponse
from DeviceServer.rest import RESTResponseType


class AttenuatorApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_attenuator_state(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        expander_index: Annotated[int, Field(le=10, strict=True, ge=1, description="expander index")],
        expander_port_index: Annotated[Optional[StrictInt], Field(description="expander port index")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AttenuationState:
        """GET attenuation state

        Get attenuation state by expander port index.

        :param device_id: (required)
        :type device_id: str
        :param expander_index: expander index (required)
        :type expander_index: int
        :param expander_port_index: expander port index
        :type expander_port_index: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_attenuator_state_serialize(
            device_id=device_id,
            expander_index=expander_index,
            expander_port_index=expander_port_index,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttenuationState",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_attenuator_state_with_http_info(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        expander_index: Annotated[int, Field(le=10, strict=True, ge=1, description="expander index")],
        expander_port_index: Annotated[Optional[StrictInt], Field(description="expander port index")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AttenuationState]:
        """GET attenuation state

        Get attenuation state by expander port index.

        :param device_id: (required)
        :type device_id: str
        :param expander_index: expander index (required)
        :type expander_index: int
        :param expander_port_index: expander port index
        :type expander_port_index: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_attenuator_state_serialize(
            device_id=device_id,
            expander_index=expander_index,
            expander_port_index=expander_port_index,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttenuationState",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_attenuator_state_without_preload_content(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        expander_index: Annotated[int, Field(le=10, strict=True, ge=1, description="expander index")],
        expander_port_index: Annotated[Optional[StrictInt], Field(description="expander port index")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """GET attenuation state

        Get attenuation state by expander port index.

        :param device_id: (required)
        :type device_id: str
        :param expander_index: expander index (required)
        :type expander_index: int
        :param expander_port_index: expander port index
        :type expander_port_index: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_attenuator_state_serialize(
            device_id=device_id,
            expander_index=expander_index,
            expander_port_index=expander_port_index,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttenuationState",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_attenuator_state_serialize(
        self,
        device_id,
        expander_index,
        expander_port_index,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if device_id is not None:
            _path_params['device_id'] = device_id
        # process the query parameters
        if expander_index is not None:
            
            _query_params.append(('expander_index', expander_index))
            
        if expander_port_index is not None:
            
            _query_params.append(('expander_port_index', expander_port_index))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/Attenuator/{device_id}/Attenuate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_channel_attenuation(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        channel_index: Annotated[int, Field(le=10, strict=True, ge=1, description="channel index")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ChannelAttenuationState:
        """GET attenuation channel state

        Get attenuation state sof selected channel

        :param device_id: (required)
        :type device_id: str
        :param channel_index: channel index (required)
        :type channel_index: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_channel_attenuation_serialize(
            device_id=device_id,
            channel_index=channel_index,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChannelAttenuationState",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_channel_attenuation_with_http_info(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        channel_index: Annotated[int, Field(le=10, strict=True, ge=1, description="channel index")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ChannelAttenuationState]:
        """GET attenuation channel state

        Get attenuation state sof selected channel

        :param device_id: (required)
        :type device_id: str
        :param channel_index: channel index (required)
        :type channel_index: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_channel_attenuation_serialize(
            device_id=device_id,
            channel_index=channel_index,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChannelAttenuationState",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_channel_attenuation_without_preload_content(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        channel_index: Annotated[int, Field(le=10, strict=True, ge=1, description="channel index")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """GET attenuation channel state

        Get attenuation state sof selected channel

        :param device_id: (required)
        :type device_id: str
        :param channel_index: channel index (required)
        :type channel_index: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_channel_attenuation_serialize(
            device_id=device_id,
            channel_index=channel_index,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChannelAttenuationState",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_channel_attenuation_serialize(
        self,
        device_id,
        channel_index,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if device_id is not None:
            _path_params['device_id'] = device_id
        # process the query parameters
        if channel_index is not None:
            
            _query_params.append(('channel_index', channel_index))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/Attenuator/{device_id}/AttenuateChannel',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_device_attenuation_configuration(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """GET attenuation device config

        Getattenuation condig sent through by the device

        :param device_id: (required)
        :type device_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_device_attenuation_configuration_serialize(
            device_id=device_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_device_attenuation_configuration_with_http_info(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """GET attenuation device config

        Getattenuation condig sent through by the device

        :param device_id: (required)
        :type device_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_device_attenuation_configuration_serialize(
            device_id=device_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_device_attenuation_configuration_without_preload_content(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """GET attenuation device config

        Getattenuation condig sent through by the device

        :param device_id: (required)
        :type device_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_device_attenuation_configuration_serialize(
            device_id=device_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "object",
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_device_attenuation_configuration_serialize(
        self,
        device_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if device_id is not None:
            _path_params['device_id'] = device_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/Attenuator/{device_id}/AttenuatorConfig',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def put_attenuator_state(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        expander_index: Annotated[StrictInt, Field(description="expander index")],
        expander_port_index: Annotated[StrictInt, Field(description="expander port")],
        value: Annotated[StrictInt, Field(description="attenuation value")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """PUT attenuation state

        Get attenuation state selected expander port

        :param device_id: (required)
        :type device_id: str
        :param expander_index: expander index (required)
        :type expander_index: int
        :param expander_port_index: expander port (required)
        :type expander_port_index: int
        :param value: attenuation value (required)
        :type value: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_attenuator_state_serialize(
            device_id=device_id,
            expander_index=expander_index,
            expander_port_index=expander_port_index,
            value=value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def put_attenuator_state_with_http_info(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        expander_index: Annotated[StrictInt, Field(description="expander index")],
        expander_port_index: Annotated[StrictInt, Field(description="expander port")],
        value: Annotated[StrictInt, Field(description="attenuation value")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """PUT attenuation state

        Get attenuation state selected expander port

        :param device_id: (required)
        :type device_id: str
        :param expander_index: expander index (required)
        :type expander_index: int
        :param expander_port_index: expander port (required)
        :type expander_port_index: int
        :param value: attenuation value (required)
        :type value: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_attenuator_state_serialize(
            device_id=device_id,
            expander_index=expander_index,
            expander_port_index=expander_port_index,
            value=value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def put_attenuator_state_without_preload_content(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        expander_index: Annotated[StrictInt, Field(description="expander index")],
        expander_port_index: Annotated[StrictInt, Field(description="expander port")],
        value: Annotated[StrictInt, Field(description="attenuation value")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """PUT attenuation state

        Get attenuation state selected expander port

        :param device_id: (required)
        :type device_id: str
        :param expander_index: expander index (required)
        :type expander_index: int
        :param expander_port_index: expander port (required)
        :type expander_port_index: int
        :param value: attenuation value (required)
        :type value: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_attenuator_state_serialize(
            device_id=device_id,
            expander_index=expander_index,
            expander_port_index=expander_port_index,
            value=value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _put_attenuator_state_serialize(
        self,
        device_id,
        expander_index,
        expander_port_index,
        value,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if device_id is not None:
            _path_params['device_id'] = device_id
        # process the query parameters
        if expander_index is not None:
            
            _query_params.append(('expander_index', expander_index))
            
        if expander_port_index is not None:
            
            _query_params.append(('expander_port_index', expander_port_index))
            
        if value is not None:
            
            _query_params.append(('value', value))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/Attenuator/{device_id}/Attenuate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def put_channel_attenuation(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        channel_index: Annotated[StrictInt, Field(description="channel index")],
        value: Annotated[StrictInt, Field(description="attenuation value")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """PUT attenuation state

        Put attenuation state of selected channel

        :param device_id: (required)
        :type device_id: str
        :param channel_index: channel index (required)
        :type channel_index: int
        :param value: attenuation value (required)
        :type value: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_channel_attenuation_serialize(
            device_id=device_id,
            channel_index=channel_index,
            value=value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def put_channel_attenuation_with_http_info(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        channel_index: Annotated[StrictInt, Field(description="channel index")],
        value: Annotated[StrictInt, Field(description="attenuation value")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """PUT attenuation state

        Put attenuation state of selected channel

        :param device_id: (required)
        :type device_id: str
        :param channel_index: channel index (required)
        :type channel_index: int
        :param value: attenuation value (required)
        :type value: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_channel_attenuation_serialize(
            device_id=device_id,
            channel_index=channel_index,
            value=value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def put_channel_attenuation_without_preload_content(
        self,
        device_id: Annotated[str, Field(min_length=36, strict=True, max_length=36)],
        channel_index: Annotated[StrictInt, Field(description="channel index")],
        value: Annotated[StrictInt, Field(description="attenuation value")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """PUT attenuation state

        Put attenuation state of selected channel

        :param device_id: (required)
        :type device_id: str
        :param channel_index: channel index (required)
        :type channel_index: int
        :param value: attenuation value (required)
        :type value: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_channel_attenuation_serialize(
            device_id=device_id,
            channel_index=channel_index,
            value=value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '405': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _put_channel_attenuation_serialize(
        self,
        device_id,
        channel_index,
        value,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if device_id is not None:
            _path_params['device_id'] = device_id
        # process the query parameters
        if channel_index is not None:
            
            _query_params.append(('channel_index', channel_index))
            
        if value is not None:
            
            _query_params.append(('value', value))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/Attenuator/{device_id}/AttenuateChannel',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.models.db_device_port import DbDevicePort

class TestDbDevicePort(unittest.TestCase):
    """DbDevicePort unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbDevicePort:
        """Test DbDevicePort
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbDevicePort`
        """
        model = DbDevicePort()
        if include_optional:
            return DbDevicePort(
                port_id = '',
                port_index = 1,
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435',
                label = '',
                state_index = 0
            )
        else:
            return DbDevicePort(
                port_id = '',
                port_index = 1,
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435',
        )
        """

    def testDbDevicePort(self):
        """Test DbDevicePort"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from DeviceServer.api.attenuator_api import AttenuatorApi
from DeviceServer.api.device_mount_system_api import DeviceMountSystemApi
from DeviceServer.api.devices_api import DevicesApi
from DeviceServer.api.docker_api import DockerApi
from DeviceServer.api.internal_api import InternalApi
from DeviceServer.api.serial_mux_api import SerialMuxApi
from DeviceServer.api.turntable_api import TurntableApi




# coding: utf-8

# flake8: noqa

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.2.2"

# import apis into sdk package
from DeviceServer.api.attenuator_api import AttenuatorApi
from DeviceServer.api.device_mount_system_api import DeviceMountSystemApi
from DeviceServer.api.devices_api import DevicesApi
from DeviceServer.api.docker_api import DockerApi
from DeviceServer.api.internal_api import InternalApi
from DeviceServer.api.serial_mux_api import SerialMuxApi
from DeviceServer.api.turntable_api import TurntableApi

# import ApiClient
from DeviceServer.api_response import ApiResponse
from DeviceServer.api_client import ApiClient
from DeviceServer.configuration import Configuration
from DeviceServer.exceptions import OpenApiException
from DeviceServer.exceptions import ApiTypeError
from DeviceServer.exceptions import ApiValueError
from DeviceServer.exceptions import ApiKeyError
from DeviceServer.exceptions import ApiAttributeError
from DeviceServer.exceptions import ApiException

# import models into sdk package
from DeviceServer.models.attenuation_state import AttenuationState
from DeviceServer.models.channel_attenuation_state import ChannelAttenuationState
from DeviceServer.models.db_button_state import DbButtonState
from DeviceServer.models.db_device_button import DbDeviceButton
from DeviceServer.models.db_device_led import DbDeviceLed
from DeviceServer.models.db_device_port import DbDevicePort
from DeviceServer.models.db_device_temperature_port import DbDeviceTemperaturePort
from DeviceServer.models.db_led_state import DbLedState
from DeviceServer.models.db_port_state import DbPortState
from DeviceServer.models.db_upload_firmware_state import DbUploadFirmwareState
from DeviceServer.models.device import Device
from DeviceServer.models.device_button import DeviceButton
from DeviceServer.models.device_led import DeviceLed
from DeviceServer.models.device_port import DevicePort
from DeviceServer.models.device_rx_buffer import DeviceRxBuffer
from DeviceServer.models.device_temperature_port import DeviceTemperaturePort
from DeviceServer.models.device_tx_buffer import DeviceTxBuffer
from DeviceServer.models.firmware_version import FirmwareVersion
from DeviceServer.models.host_config import HostConfig
from DeviceServer.models.led_state import LedState
from DeviceServer.models.port_state import PortState
from DeviceServer.models.post_verify_user_access_request import PostVerifyUserAccessRequest
from DeviceServer.models.put_device_device_id_description200_response import PutDeviceDeviceIdDescription200Response
from DeviceServer.models.put_device_device_id_name200_response import PutDeviceDeviceIdName200Response
from DeviceServer.models.relay_state import RelayState
from DeviceServer.models.temp_range import TempRange
from DeviceServer.models.temperature import Temperature



# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.attenuator_api import AttenuatorApi


class TestAttenuatorApi(unittest.TestCase):
    """AttenuatorApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AttenuatorApi()

    def tearDown(self) -> None:
        pass

    def test_get_attenuator_state(self) -> None:
        """Test case for get_attenuator_state

        GET attenuation state
        """
        pass

    def test_get_channel_attenuation(self) -> None:
        """Test case for get_channel_attenuation

        GET attenuation channel state
        """
        pass

    def test_get_device_attenuation_configuration(self) -> None:
        """Test case for get_device_attenuation_configuration

        GET attenuation device config
        """
        pass

    def test_put_attenuator_state(self) -> None:
        """Test case for put_attenuator_state

        PUT attenuation state
        """
        pass

    def test_put_channel_attenuation(self) -> None:
        """Test case for put_channel_attenuation

        PUT attenuation state
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.models.post_verify_user_access_request import PostVerifyUserAccessRequest

class TestPostVerifyUserAccessRequest(unittest.TestCase):
    """PostVerifyUserAccessRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PostVerifyUserAccessRequest:
        """Test PostVerifyUserAccessRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PostVerifyUserAccessRequest`
        """
        model = PostVerifyUserAccessRequest()
        if include_optional:
            return PostVerifyUserAccessRequest(
                acc = 56,
                clientid = '',
                topic = ''
            )
        else:
            return PostVerifyUserAccessRequest(
                acc = 56,
                clientid = '',
                topic = '',
        )
        """

    def testPostVerifyUserAccessRequest(self):
        """Test PostVerifyUserAccessRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
